@@ -37,6 +37,7 @@ from typing import Any, Generator, List, Set, Tuple, Type, Union
 # 3rd party
 from consolekit.terminal_colours import Fore
 from domdf_python_tools.paths import PathPlus
+from domdf_python_tools.typing import PathLike
 from domdf_python_tools.utils import stderr_writer
 
 # this package
@@ -45,7 +46,7 @@ from flake8_dunder_all.utils import get_docstring_lineno, mark_text_ranges
 __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020 Dominic Davis-Foster"
 __license__: str = "MIT"
-__version__: str = "0.1.3"
+__version__: str = "0.1.4"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __all__ = ["Visitor", "Plugin", "check_and_add_all", "DALL000"]
@@ -62,7 +63,7 @@ class Visitor(ast.NodeVisitor):
 		:func:`flake8_dunder_all.utils.mark_text_ranges``.
 	"""
 
-	found_all: bool  #: Flag to indicate a ``__all__`` variable has been found in the AST.
+	found_all: bool  #: Flag to indicate a ``__all__`` declaration has been found in the AST.
 	last_import: int  #: The lineno of the last top-level import
 	members: Set[str]  #: List of functions and classed defined in the AST
 	use_endlineno: bool
@@ -184,7 +185,7 @@ class Visitor(ast.NodeVisitor):
 
 class Plugin:
 	"""
-	A Flake8 plugin which checks to ensure modules have defined '__all__'.
+	A Flake8 plugin which checks to ensure modules have defined ``__all__``.
 
 	:param tree: The abstract syntax tree (AST) to check.
 	"""
@@ -218,14 +219,14 @@ class Plugin:
 			yield 0, 0, DALL000, type(self)
 
 
-def check_and_add_all(filename: PathPlus, quote_type: str = '"') -> int:
+def check_and_add_all(filename: PathLike, quote_type: str = '"') -> int:
 	"""
-	Check the given filename for the presence of a ``__all__`` variable, and add one if none is found.
+	Check the given filename for the presence of a ``__all__`` declaration, and add one if none is found.
 
 	:param filename: The filename of the Python source file (``.py``) to check.
 	:param quote_type: The type of quote to use for strings.
 
-	:returns: ``0`` if the file already contains a ``__all__`` variable or has no function or class definitions;
+	:returns: ``0`` if the file already contains a ``__all__`` declaration or has no function or class definitions;
 		``1`` otherwise. ``4`` indicates an error parsing the file.
 	"""
 
@@ -240,6 +241,7 @@ def check_and_add_all(filename: PathPlus, quote_type: str = '"') -> int:
 		tree = ast.parse(source)
 		if sys.version_info < (3, 8):  # pragma: no cover (<py38)
 			mark_text_ranges(tree, source)
+
 	except SyntaxError:
 		stderr_writer(Fore.RED(f"'{filename}' does not appear to be a valid Python source file."))
 		return 4
